@@ -49,6 +49,7 @@ class SlackBot(StreamHandler):
                  bot_name: str = None,
                  alert_level: int = 30,
                  formatter: Formatter = None,
+                 message_prefix: str = None,
                  ):
         """
         A basic Slack bot that will message users and channels
@@ -60,6 +61,8 @@ class SlackBot(StreamHandler):
         :param str channel_name: channel to message on. for example, #channelname
         :param alert_level: alert level to notify the defined user at
         :param formatter: logging formatter to use (if not specified, the class DEFAULT_FORMATTER is used)
+        :param message_prefix: adds a message prefix to all logging messages emitted (for source identification if there
+            are multiple systems leveraging a single bot account)
         """
         StreamHandler.__init__(self)
         if formatter is None:
@@ -70,6 +73,7 @@ class SlackBot(StreamHandler):
         self._channel = DEFAULT_CHANNEL_NAME
         self._bot_token = BOT_TOKEN
         self._bot_web_client = None
+        self.message_prefix: str = message_prefix
 
         if bot_name is not None:  # v2.3
             warnings.warn(
@@ -226,6 +230,8 @@ class SlackBot(StreamHandler):
         """function required for logging StreamHandling, not intended for direct interaction"""
         # catch and format message
         msg = self.format(record)
+        if self.message_prefix is not None:
+            msg = f'{self.message_prefix} {msg}'
         # determine whether to tag admin
         tag_admin = True if record.levelno >= self.alert_level else False
         self.post_slack_message(
